package com.huigou.topsun.sap.nonProdApply.application.impl;


import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.huigou.topsun.base.bsnMessage.appliction.BsnMessageApplication;
import com.huigou.topsun.base.bsnMessage.domain.ActiveStatus;
import com.huigou.topsun.base.bsnMessage.domain.BsnMessageExecute;
import com.huigou.topsun.base.bsnMessage.domain.BsnMessageSponsor;
import com.huigou.topsun.sap.nonProdApply.application.NonProdApplyDeptApplication;

import com.huigou.topsun.sap.nonProdApply.domain.SapNonProdApplyDept;
import com.huigou.topsun.sap.nonProdApply.repository.NonProdApplyDeptRepository;
import com.huigou.uasp.bmp.common.application.BaseApplication;

import com.huigou.util.SDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class NonProdApplyDeptApplicationImpl extends BaseApplication implements NonProdApplyDeptApplication {

    @Autowired
    NonProdApplyDeptRepository nonProdApplyDeptRepository;
    @Autowired
    BsnMessageApplication bsnMessageApplication;

    @Override
    public Map<String,Object> saveSapNonProdApplyDept(SDO sdo){
        Map<String,Object> map = new HashMap<>();
        SapNonProdApplyDept nonProdApplyDept = sdo.toObject(SapNonProdApplyDept.class);
        nonProdApplyDept = nonProdApplyDeptRepository.save(nonProdApplyDept);

        //获取分发的部门与人员信息
        ObjectMapper objectMapper = new ObjectMapper();
        String deptStaffJSON = sdo.getString("deptStaff");
        List<Map<String, String>> deptStaffList = null;
        try {
            deptStaffList = objectMapper.readValue(deptStaffJSON, new TypeReference<List<Map<String, String>>>() {});
        } catch (JsonProcessingException e) {
            throw new RuntimeException("JSON转换失败："+e);
        }

        //封装分发数据
        BsnMessageSponsor bsnMessageSponsor = new BsnMessageSponsor();
        bsnMessageSponsor.setTaskSponsor(this.getOperator().getUserId());
        bsnMessageSponsor.setTitle("非产品/非本成品类物料");
        bsnMessageSponsor.setExecutorUrl("sapNonProdApplyNext/fillInNonProdApplyDept.do");
        bsnMessageSponsor.setCreateDate(new Date());
        bsnMessageSponsor.setBusinessId(nonProdApplyDept.getApplyDeptId());
        bsnMessageSponsor.setStatus(0);

        List<BsnMessageExecute> executeList = new ArrayList<>();
        for (Map<String, String> stringMap : deptStaffList) {
            BsnMessageExecute messageExecute = new BsnMessageExecute();
            String userCode = stringMap.get("userCode");
            String deptName = stringMap.get("deptName");
            String deptCode = stringMap.get("deptCode");

            messageExecute.setTaskExecute(userCode);
            messageExecute.setBusinessCode(deptCode);
            messageExecute.setActive(ActiveStatus.SAVED.getValue());
            messageExecute.setCreateDate(new Date());
            messageExecute.setTaskDescribe(deptName+"部门数据维护");
            executeList.add(messageExecute);
        }
        bsnMessageSponsor.setExecutes(executeList);
        String keyId = bsnMessageApplication.saveBsnMessageSponsor(bsnMessageSponsor);

        map.put("applyDeptId",nonProdApplyDept.getApplyDeptId());
        map.put("keyId",keyId);
        return map;
    }

    @Override
    public void distributeSapNonProdApplyDept(SDO sdo) {
        //将状态为保存为分发的全部修改为分发未完成
        Map<String, Object> map = this.saveSapNonProdApplyDept(sdo);
        List<BsnMessageExecute> executes = bsnMessageApplication.getExecuteByMsId((String) map.get("keyId"));
        executes.forEach(item->item.setActive(ActiveStatus.UNFINISHED.getValue()));
        bsnMessageApplication.saveBsnMessageExecute(executes);
    }

    @Override
    public SapNonProdApplyDept getNonProdApplyDeptById(String id) {
        return nonProdApplyDeptRepository.findOne(id);
    }


    @Override
    public void rejectNonProdApplyDept(SDO sdo) {
        String septString = sdo.getString("dept");
        //需要被驳回的部门
        List<String> deptList = Arrays.asList(septString.split(","));
        String bdid = sdo.getString("表单的id");
        //更改状态此对象为驳回状态
        SapNonProdApplyDept one = nonProdApplyDeptRepository.findOne(bdid);
        one.setStatus(ActiveStatus.REJECTED.getValue());
        nonProdApplyDeptRepository.save(one);
        //获取此条数据的相关部门信息
//        List<BsnMessage> allByBusinessId = bsnMessageRepository.findAllByBusinessId(bdid);
    }
}
